badwing.character.controller package
====================================

Submodules
----------

badwing.character.controller.controller module
----------------------------------------------

.. automodule:: badwing.character.controller.controller
   :members:
   :undoc-members:
   :show-inheritance:

badwing.character.controller.kinematic module
---------------------------------------------

.. automodule:: badwing.character.controller.kinematic
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.character.controller
   :members:
   :undoc-members:
   :show-inheritance:
